@@ -25,12 +25,19 @@ class SendGridClient(object):
         """
         self.username = username
         self.password = password
-        self.mail_url = 'https://api.sendgrid.com/api/mail.send.json'
-
+        self.host = opts.get('host', 'https://api.sendgrid.com')
+        self.port = opts.get('port', '443')
+        self.endpoint = '/api/mail.send.json'
+        self.mail_url = self.host + ':' + self.port + self.endpoint
         # urllib cannot connect to SSL servers using proxies
         self.proxies = opts.get('proxies', None)
 
     def _build_body(self, message):
+        if sys.version_info < (3,0):
+            message.subject = message.subject.encode('utf-8')
+            message.text = message.text.encode('utf-8')
+            message.html = message.html.encode('utf-8')
+
         values = {
             'api_user': self.username,
             'api_key': self.password,
